package bdd;

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import androidx.annotation.Nullable;

public class CreateBdDepannTout extends SQLiteOpenHelper {

    public static final String TABLE_CLIENT = "client";
    public static final String TABLE_INTER = "intervention";

    private static final String CREATE_TABLE_CLIENT =
            "CREATE TABLE " + TABLE_CLIENT + "(" +
                    "id INTEGER PRIMARY KEY AUTOINCREMENT, " +
                    "nom TEXT NOT NULL, " +
                    "prenom TEXT NOT NULL, " +
                    "numTel TEXT NOT NULL, " +
                    "adrMail TEXT NOT NULL, " +
                    "adrPostale TEXT NOT NULL);";

    private static final String CREATE_TABLE_INTER =
            "CREATE TABLE " + TABLE_INTER + "(" +
                    "id INTEGER PRIMARY KEY AUTOINCREMENT, " +
                    "cliId INTEGER NOT NULL, " +
                    "dateTime TEXT NOT NULL, " +
                    "observation TEXT NOT NULL, " +
                    "FOREIGN KEY (cliId) REFERENCES " + TABLE_CLIENT + "(id) ON DELETE CASCADE);";

    public CreateBdDepannTout(@Nullable Context context, @Nullable String name,
                              @Nullable SQLiteDatabase.CursorFactory factory, int version) {
        super(context, name, factory, version);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        db.execSQL(CREATE_TABLE_CLIENT);
        Log.d("bdd", "Table client créée");

        db.execSQL(CREATE_TABLE_INTER);
        Log.d("bdd", "Table intervention créée");

    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        Log.d("bdd", "Mise à jour de la base : suppression et recréation");
        db.execSQL("DROP TABLE IF EXISTS " + TABLE_INTER);
        db.execSQL("DROP TABLE IF EXISTS " + TABLE_CLIENT);
        onCreate(db);
    }

    @Override
    public void onDowngrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        Log.d("bdd", "Downgrade détecté : suppression et recréation de la base");
        onUpgrade(db, oldVersion, newVersion);
    }
    @Override
    public void onOpen(SQLiteDatabase db) {
        super.onOpen(db);
        if (!db.isReadOnly()) {
            db.execSQL("PRAGMA foreign_keys=ON;");
        }
    }

}
